#[non_exhaustive]pub enum MaxMindDbError {
InvalidDatabase {
message: String,
offset: Option<usize>,
},
Io(Error),
Mmap(Error),
Decoding {
message: String,
offset: Option<usize>,
path: Option<String>,
},
ResourceLimit {
message: String,
offset: Option<usize>,
path: Option<String>,
},
InvalidNetwork(IpNetworkError),
InvalidInput {
message: String,
},
}Expand description
Error returned by MaxMind DB operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidDatabase
The database file is invalid or corrupted.
Fields
Io(Error)
An I/O error occurred while reading the database.
Mmap(Error)
Memory mapping failed.
Decoding
Error decoding data from the database.
Fields
ResourceLimit
Decoding or verification stopped because it exceeded an expansion or work safety limit.
This does not necessarily mean that the database is structurally
invalid. Schema-specific limits reported by a custom Serde visitor use
MaxMindDbError::Decoding instead. Applications may choose a narrower
schema or reject the database as untrusted input.
Fields
InvalidNetwork(IpNetworkError)
The provided network/CIDR is invalid.
InvalidInput
The provided input is invalid for this operation.
Implementations
Sourceimpl MaxMindDbError
impl MaxMindDbError
Sourcepub fn invalid_database(message: impl Into<String>) -> Self
pub fn invalid_database(message: impl Into<String>) -> Self
Creates an InvalidDatabase error with just a message.
Sourcepub fn invalid_database_at(message: impl Into<String>, offset: usize) -> Self
pub fn invalid_database_at(message: impl Into<String>, offset: usize) -> Self
Creates an InvalidDatabase error with message and offset.
Sourcepub fn decoding(message: impl Into<String>) -> Self
pub fn decoding(message: impl Into<String>) -> Self
Creates a Decoding error with just a message.
Sourcepub fn decoding_at(message: impl Into<String>, offset: usize) -> Self
pub fn decoding_at(message: impl Into<String>, offset: usize) -> Self
Creates a Decoding error with message and offset.
Sourcepub fn decoding_at_path(
message: impl Into<String>,
offset: usize,
path: impl Into<String>,
) -> Self
pub fn decoding_at_path( message: impl Into<String>, offset: usize, path: impl Into<String>, ) -> Self
Creates a Decoding error with message, offset, and path.
Sourcepub fn resource_limit_at(message: impl Into<String>, offset: usize) -> Self
pub fn resource_limit_at(message: impl Into<String>, offset: usize) -> Self
Creates a ResourceLimit error with a message and offset.
Sourcepub fn invalid_input(message: impl Into<String>) -> Self
pub fn invalid_input(message: impl Into<String>) -> Self
Creates an InvalidInput error.